@@ -7,7 +7,6 @@ except ImportError:
 
 from datetime import datetime
 
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
 from django.contrib.auth.models import User
@@ -20,10 +19,13 @@ try:
 except ImportError:
     twitter = None
 
+from biblion.conf import settings
 from biblion.managers import PostManager
-from biblion.settings import ALL_SECTION_NAME, SECTIONS, MARKUP_CHOICES
 from biblion.utils import can_tweet
 
+from string import letters
+from random import choice
+
 
 def ig(L, i):
     for x in L:
@@ -32,7 +34,11 @@ def ig(L, i):
 
 class Post(models.Model):
 
-    SECTION_CHOICES = [(1, ALL_SECTION_NAME)] + zip(range(2, 2 + len(SECTIONS)), ig(SECTIONS, 1))
+    SECTION_CHOICES = [(1, settings.BIBLION_ALL_SECTION_NAME)] + \
+        zip(
+            range(2, 2 + len(settings.BIBLION_SECTIONS)),
+            ig(settings.BIBLION_SECTIONS, 1)
+        )
 
     section = models.IntegerField(choices=SECTION_CHOICES)
 
@@ -40,7 +46,7 @@ class Post(models.Model):
     slug = models.SlugField()
     author = models.ForeignKey(User, related_name="posts")
 
-    markup = models.CharField(max_length=25, choices=MARKUP_CHOICES)
+    markup = models.CharField(max_length=25, choices=settings.BIBLION_MARKUP_CHOICES)
 
     teaser_html = models.TextField(editable=False)
     content_html = models.TextField(editable=False)
@@ -48,9 +54,16 @@ class Post(models.Model):
     tweet_text = models.CharField(max_length=140, editable=False)
 
     created = models.DateTimeField(default=datetime.now, editable=False)  # when first revision was created
-    updated = models.DateTimeField(null=True, blank=True, editable=False)  # when last revision was create (even if not published)
+    updated = models.DateTimeField(null=True, blank=True, editable=False)  # when last revision was created (even if not published)
     published = models.DateTimeField(null=True, blank=True, editable=False)  # when last published
 
+    secret_key = models.CharField(
+        max_length=8,
+        blank=True,
+        unique=True,
+        help_text="allows url for sharing unpublished posts to unauthenticated users"
+    )
+
     view_count = models.IntegerField(default=0, editable=False)
 
     @staticmethod
@@ -58,9 +71,9 @@ class Post(models.Model):
         """
         given a slug return the index for it
         """
-        if slug == ALL_SECTION_NAME:
+        if slug == settings.BIBLION_ALL_SECTION_NAME:
             return 1
-        return dict(zip(ig(SECTIONS, 0), range(2, 2 + len(SECTIONS))))[slug]
+        return dict(zip(ig(settings.BIBLION_SECTIONS, 0), range(2, 2 + len(settings.BIBLION_SECTIONS))))[slug]
 
     @property
     def section_slug(self):
@@ -69,8 +82,8 @@ class Post(models.Model):
         need a property to turn them back into their slug form
         """
         if self.section == 1:
-            return ALL_SECTION_NAME
-        return dict(zip(range(2, 2 + len(SECTIONS)), ig(SECTIONS, 0)))[self.section]
+            return settings.BIBLION_ALL_SECTION_NAME
+        return dict(zip(range(2, 2 + len(settings.BIBLION_SECTIONS)), ig(settings.BIBLION_SECTIONS, 0)))[self.section]
 
     def rev(self, rev_id):
         return self.revisions.get(pk=rev_id)
@@ -127,8 +140,25 @@ class Post(models.Model):
 
     def save(self, **kwargs):
         self.updated_at = datetime.now()
+        if not self.secret_key:
+            # Generate a random secret key
+            self.secret_key = "".join(choice(letters) for _ in xrange(8))
         super(Post, self).save(**kwargs)
 
+    @property
+    def sharable_url(self):
+        """
+        An url to reach this post (there is a secret url for sharing unpublished
+        posts to outside users).
+        """
+        if not self.published:
+            if self.secret_key:
+                return reverse("blog_post_secret", kwargs={"post_secret_key": self.secret_key})
+            else:
+                return "A secret sharable url for non-authenticated users is generated when you save this post."
+        else:
+            return self.get_absolute_url()
+
     def get_absolute_url(self):
         if self.published:
             name = "blog_post"
@@ -195,3 +225,12 @@ class FeedHit(models.Model):
 
     request_data = models.TextField()
     created = models.DateTimeField(default=datetime.now)
+
+
+class ReviewComment(models.Model):
+
+    post = models.ForeignKey(Post, related_name="review_comments")
+
+    review_text = models.TextField()
+    timestamp = models.DateTimeField(default=datetime.now)
+    addressed = models.BooleanField(default=False)
